@@ -1,9 +1,10 @@
 
 
-__version__ = '0.1.8'
+__version__ = '0.1.9'
 
 from .compiler import SassCompiler
 from .watch import SassObserver
+from .manifest import Manifest
 
 def get_css(sass, lib_dirs=None):
     c = SassCompiler(lib_dirs=lib_dirs)
@@ -26,6 +27,7 @@ __all__ = ['__version__',
            'get_css',
            'get_scss',
            'SassCompiler',
-           'SassObserver']
+           'SassObserver',
+           'Manifest']
 
 
